﻿module Util
open System.Drawing

let random_gen = new System.Random()

let rand_int min max =
    random_gen.Next(min, max)

let rand_float min max = 
    min + (float32 (random_gen.NextDouble())) * (max - min)

let inline pow a b =
    float32 (System.Math.Pow(float a, float b))

let inline clamp v min max =
    if v < min then min elif v > max then max else v

let map_range fmin fto tmin tto v =
    let t =
        if fmin = fto then 
            0.f
        elif fmin < fto then
            clamp ((v - fmin) / (fto - fmin)) 0.f 1.f
        else
            clamp ((fmin - v) / (fmin - fto)) 0.f 1.f
    tmin + t * (tto - tmin)

let inline lerp a b t =
    a + t * (b - a)

let inline color_f2i v =
    clamp (int (v * 255.f)) 0 255

let lerp_color (c1:Color) (c2:Color) t =
    let a = clamp (int (lerp (float32 c1.A) (float32 c2.A) t)) 0 255
    let r = clamp (int (lerp (float32 c1.R) (float32 c2.R) t)) 0 255
    let g = clamp (int (lerp (float32 c1.G) (float32 c2.G) t)) 0 255
    let b = clamp (int (lerp (float32 c1.B) (float32 c2.B) t)) 0 255
    Color.FromArgb(a, r, g, b)
