﻿module Vec2

let zero = (0.f, 0.f)

let inline create x y =
    (x, y)

let inline add (x1, y1) (x2, y2) =
    (x1 + x2, y1 + y2)

let inline add_mul (x1, y1) (x2, y2) v =
    (x1 + x2 * v, y1 + y2 * v)

let inline sub (x1, y1) (x2, y2) =
    (x1 - x2, y1 - y2)

let inline scale (x, y) v =
    (x * v, y * v)

let inline dot (x1, y1) (x2, y2) =
    x1 * x2 + y1 * y2

let inline norm v =
    dot v v
    
let inline abs v =
    sqrt (norm v)

let inline get_normal (x, y) =
    (y, -x)

let inline unit_or_zero v =
    let len = abs v
    if len < 0.0001f then
        (0.f, 0.f)
    else
        scale v (1.f / len)

let inline lerp a b t =
    add a (scale (sub b a) t)

let inline scale_away pos from amt =
    let dir = unit_or_zero (sub pos from)
    add_mul pos dir amt
